aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMike Schuchardt <mikes@lunarg.com>2025-11-21 09:14:07 -0800
committerMike Schuchardt <mikes@lunarg.com>2025-11-24 07:57:23 -0800
commit6e586b25268ff24040c576594a72b1436b2cb12d (patch)
treee9c8c42042b656c8915f01b67205511095fe2959
parent013058f74e2356347f8d9317233bc769816c9dfb (diff)
downloadusermoji-6e586b25268ff24040c576594a72b1436b2cb12d.tar.xz
build: Update to header 1.4.334
-rw-r--r--CMakeLists.txt2
-rw-r--r--icd/VkICD_mock_icd.json.in2
-rw-r--r--icd/generated/vk_typemap_helper.h19
-rw-r--r--scripts/known_good.json4
-rw-r--r--vulkaninfo/generated/vulkaninfo.hpp10
5 files changed, 20 insertions, 17 deletions
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 58e2abef..a8daf76b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -18,7 +18,7 @@
cmake_minimum_required(VERSION 3.22.1)
# The VERSION field is generated with the "--generated-version" flag in the generate_source.py script
-project(Vulkan-Tools VERSION 1.4.333)
+project(Vulkan-Tools VERSION 1.4.334)
# This variable enables downstream users to customize the target API
# variant (e.g. Vulkan SC)
diff --git a/icd/VkICD_mock_icd.json.in b/icd/VkICD_mock_icd.json.in
index 4a99f170..86b3953b 100644
--- a/icd/VkICD_mock_icd.json.in
+++ b/icd/VkICD_mock_icd.json.in
@@ -2,6 +2,6 @@
"file_format_version": "1.0.1",
"ICD": {
"library_path": "@JSON_LIBRARY_PATH@",
- "api_version": "1.4.333"
+ "api_version": "1.4.334"
}
} \ No newline at end of file
diff --git a/scripts/known_good.json b/scripts/known_good.json
index cb3bac96..0eaa0a99 100644
--- a/scripts/known_good.json
+++ b/scripts/known_good.json
@@ -7,7 +7,7 @@
"sub_dir": "Vulkan-Headers",
"build_dir": "Vulkan-Headers/build",
"install_dir": "Vulkan-Headers/build/install",
- "commit": "v1.4.333"
+ "commit": "v1.4.334"
},
{
"name": "MoltenVK",
@@ -56,7 +56,7 @@
"cmake_options": [
"-DLOADER_USE_UNSAFE_FILE_SEARCH=ON"
],
- "commit": "v1.4.333",
+ "commit": "v1.4.334",
"build_platforms": [
"windows",
"linux",
diff --git a/vulkaninfo/generated/vulkaninfo.hpp b/vulkaninfo/generated/vulkaninfo.hpp
index 005fc6a0..31cf38da 100644
--- a/vulkaninfo/generated/vulkaninfo.hpp
+++ b/vulkaninfo/generated/vulkaninfo.hpp
@@ -7201,8 +7201,7 @@ struct phys_device_features2_chain {
chain_members.push_back(reinterpret_cast<VkBaseOutStructure*>(&PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT));
if (gpu.CheckPhysicalDeviceExtensionIncluded(VK_KHR_RAY_QUERY_EXTENSION_NAME))
chain_members.push_back(reinterpret_cast<VkBaseOutStructure*>(&PhysicalDeviceRayQueryFeaturesKHR));
- if (gpu.CheckPhysicalDeviceExtensionIncluded(VK_NV_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME)
- || gpu.CheckPhysicalDeviceExtensionIncluded(VK_EXT_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME))
+ if (gpu.CheckPhysicalDeviceExtensionIncluded(VK_EXT_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME))
chain_members.push_back(reinterpret_cast<VkBaseOutStructure*>(&PhysicalDeviceRayTracingInvocationReorderFeaturesEXT));
if (gpu.CheckPhysicalDeviceExtensionIncluded(VK_KHR_RAY_TRACING_MAINTENANCE_1_EXTENSION_NAME))
chain_members.push_back(reinterpret_cast<VkBaseOutStructure*>(&PhysicalDeviceRayTracingMaintenance1FeaturesKHR));
@@ -8145,13 +8144,8 @@ void chain_iterator_phys_device_features2(Printer &p, AppGpu &gpu, bool show_pro
}
if (structure->sType == VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT) {
const VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT* props = (const VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT*)structure;
- const char* name = gpu.CheckPhysicalDeviceExtensionIncluded(VK_EXT_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME) ? "VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT" : ("VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV");
+ const char* name = "VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT";
DumpVkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT(p, name, *props);
- if (show_promoted_structs && strcmp(name, "VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV") != 0 && gpu.CheckPhysicalDeviceExtensionIncluded(VK_NV_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME)) {
- p.AddNewline();
- p.SetSubHeader();
- DumpVkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT(p, "VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV", *props);
- }
p.AddNewline();
}
if (structure->sType == VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_MAINTENANCE_1_FEATURES_KHR) {
diff --git a/icd/generated/vk_typemap_helper.h b/icd/generated/vk_typemap_helper.h
index 059430b0..a371e72c 100644
--- a/icd/generated/vk_typemap_helper.h
+++ b/icd/generated/vk_typemap_helper.h
@@ -8827,13 +8827,13 @@ template <> struct LvlSTypeMap<VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INV
typedef VkPhysicalDeviceRayTracingInvocationReorderPropertiesNV Type;
};
-// Map type VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT to id VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT
-template <> struct LvlTypeMap<VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT> {
- static const VkStructureType kSType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT;
+// Map type VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV to id VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_NV
+template <> struct LvlTypeMap<VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV> {
+ static const VkStructureType kSType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_NV;
};
-template <> struct LvlSTypeMap<VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT> {
- typedef VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT Type;
+template <> struct LvlSTypeMap<VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_NV> {
+ typedef VkPhysicalDeviceRayTracingInvocationReorderFeaturesNV Type;
};
// Map type VkPhysicalDeviceCooperativeVectorPropertiesNV to id VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_COOPERATIVE_VECTOR_PROPERTIES_NV
@@ -9863,6 +9863,15 @@ template <> struct LvlSTypeMap<VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INV
typedef VkPhysicalDeviceRayTracingInvocationReorderPropertiesEXT Type;
};
+// Map type VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT to id VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT
+template <> struct LvlTypeMap<VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT> {
+ static const VkStructureType kSType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT;
+};
+
+template <> struct LvlSTypeMap<VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_RAY_TRACING_INVOCATION_REORDER_FEATURES_EXT> {
+ typedef VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT Type;
+};
+
// Map type VkPhysicalDeviceDepthClampControlFeaturesEXT to id VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_DEPTH_CLAMP_CONTROL_FEATURES_EXT
template <> struct LvlTypeMap<VkPhysicalDeviceDepthClampControlFeaturesEXT> {
static const VkStructureType kSType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_DEPTH_CLAMP_CONTROL_FEATURES_EXT;